@@ -2,8 +2,10 @@
 RAVEN_IGNORABLE_USER_AGENTS = [
     r'^.*AhrefsBot.*$',
     r'^.*EasouSpider.*$',
+    r'^.*FacebookBot.*$',
     r'^.*Feedfetcher-Google.*$',
     r'^.*Googlebot.*$',
+    r'^.*Test Certificate Info.*$',
     r'^.*Twitterbot.*$',
     r'^.*Yahoo! Slurp.*$',
     r'^.*YandexBot.*$',
